#include <util/delay.h>

#include "usart.h"
#include "vibration_sensor.h"
#include "servo.h"
#include "led.h"
#include "timer.h"
#include "knock_module.h"

void initialise_environment(void)
{
	/* Sets the PD6 pin (push button) as input */
	DDRD &= ~(1 << PD6);
	
	/* Initializes the LEDs */
	LED_init();
	
	/* Initializes the USART controller */
	USART_init();
	
	/* Initializes the ADC */
	ADC_init();
	
	/* Initializes the micro servo */
	servo_init();
	
	/* Initializes the global timer */
	timer_init();
	
	/* Lights the red LED to simulate a loading */
	PORTD |= (1 << PD7);
	_delay_ms(1000);
}

int main(void)
{
	initialise_environment();
	
	while(1)
	{
		if ((PIND & (1 << PD6)) == 0) {
			_delay_ms(500);
			
			/* Turns off the green LED */
			PORTC &= ~(1 << PC0);
			
			program_knock();
		} else {
			listen_knock();
			
			/* Turns off the red LED */
			PORTD &= ~(1 << PD7);
		}
		
		#ifdef DEBUG
		ADC_print();
		#endif
	}
	
	return 0;
}
